# koyo

[![License](https://img.shields.io/pypi/l/koyo.svg?color=green)](https://github.com/vandeplaslab/koyo/raw/main/LICENSE)
[![PyPI](https://img.shields.io/pypi/v/koyo.svg?color=green)](https://pypi.org/project/koyo)
[![Python Version](https://img.shields.io/pypi/pyversions/koyo.svg?color=green)](https://python.org)
[![CI](https://github.com/vandeplaslab/koyo/actions/workflows/ci.yml/badge.svg)](https://github.com/vandeplaslab/koyo/actions/workflows/ci.yml)
[![codecov](https://codecov.io/gh/vandeplaslab/koyo/branch/main/graph/badge.svg)](https://codecov.io/gh/vandeplaslab/koyo)

Set of utility functions that are used throughout various libraries of the Van de Plas Lab.

## Installation

```bash
pip install koyo
```

## Contributing

Contributions are always welcome. Please feel free to submit PRs with new features, bug fixes, or documentation improvements.